# Internationalization (i18n)

Internationalization utilities for client-side localization. See [How to Internationalize Your Plugin](https://developer.wordpress.org/plugins/internationalization/how-to-internationalize-your-plugin/) for server-side documentation.

## Installation

Install the module:

```bash
npm install @wordpress/i18n --save
```

_This package assumes that your code will run in an **ES2015+** environment. If you're using an environment that has limited or no support for ES2015+ such as lower versions of IE then using [core-js](https://github.com/zloirock/core-js) or [@babel/polyfill](https://babeljs.io/docs/en/next/babel-polyfill) will add support for these methods. Learn more about it in [Babel docs](https://babeljs.io/docs/en/next/caveats)._

## Usage

```js
import { sprintf, _n } from '@wordpress/i18n';

sprintf( _n( '%d hat', '%d hats', 4, 'text-domain' ), 4 );
// 4 hats
```

For a complete example, see the [Internationalization section of the Block Editor Handbook](https://developer.wordpress.org/block-editor/developers/internationalization/).

## API

<!-- START TOKEN(Autogenerated API docs) -->

<a name="createI18n" href="#createI18n">#</a> **createI18n**

Create an i18n instance

_Parameters_

-   _initialData_ `[LocaleData]`: Locale data configuration.
-   _initialDomain_ `[string]`: Domain for which configuration applies.

_Returns_

-   `I18n`: I18n instance

<a name="isRTL" href="#isRTL">#</a> **isRTL**

Check if current locale is RTL.

**RTL (Right To Left)** is a locale property indicating that text is written from right to left.
For example, the `he` locale (for Hebrew) specifies right-to-left. Arabic (ar) is another common
language written RTL. The opposite of RTL, LTR (Left To Right) is used in other languages,
including English (`en`, `en-US`, `en-GB`, etc.), Spanish (`es`), and French (`fr`).

_Returns_

-   `boolean`: Whether locale is RTL.

<a name="setLocaleData" href="#setLocaleData">#</a> **setLocaleData**

Merges locale data into the Tannin instance by domain. Accepts data in a
Jed-formatted JSON object shape.

_Related_

-   <http://messageformat.github.io/Jed/>

_Parameters_

-   _data_ `[LocaleData]`: Locale data configuration.
-   _domain_ `[string]`: Domain for which configuration applies.

<a name="sprintf" href="#sprintf">#</a> **sprintf**

Returns a formatted string. If an error occurs in applying the format, the
original format string is returned.

_Related_

-   <http://www.diveintojavascript.com/projects/javascript-sprintf>

_Parameters_

-   _format_ `string`: The format of the string to generate.
-   _args_ `...*`: Arguments to apply to the format.

_Returns_

-   `string`: The formatted string.

<a name="_n" href="#_n">#</a> **\_n**

Translates and retrieves the singular or plural form based on the supplied
number.

_Related_

-   <https://developer.wordpress.org/reference/functions/_n/>

_Parameters_

-   _single_ `string`: The text to be used if the number is singular.
-   _plural_ `string`: The text to be used if the number is plural.
-   _number_ `number`: The number to compare against to use either the singular or plural form.
-   _domain_ `[string]`: Domain to retrieve the translated text.

_Returns_

-   `string`: The translated singular or plural form.

<a name="_nx" href="#_nx">#</a> **\_nx**

Translates and retrieves the singular or plural form based on the supplied
number, with gettext context.

_Related_

-   <https://developer.wordpress.org/reference/functions/_nx/>

_Parameters_

-   _single_ `string`: The text to be used if the number is singular.
-   _plural_ `string`: The text to be used if the number is plural.
-   _number_ `number`: The number to compare against to use either the singular or plural form.
-   _context_ `string`: Context information for the translators.
-   _domain_ `[string]`: Domain to retrieve the translated text.

_Returns_

-   `string`: The translated singular or plural form.

<a name="_x" href="#_x">#</a> **\_x**

Retrieve translated string with gettext context.

_Related_

-   <https://developer.wordpress.org/reference/functions/_x/>

_Parameters_

-   _text_ `string`: Text to translate.
-   _context_ `string`: Context information for the translators.
-   _domain_ `[string]`: Domain to retrieve the translated text.

_Returns_

-   `string`: Translated context string without pipe.

<a name="__" href="#__">#</a> **\_\_**

Retrieve the translation of text.

_Related_

-   <https://developer.wordpress.org/reference/functions/__/>

_Parameters_

-   _text_ `string`: Text to translate.
-   _domain_ `[string]`: Domain to retrieve the translated text.

_Returns_

-   `string`: Translated text.


<!-- END TOKEN(Autogenerated API docs) -->

<br/><br/><p align="center"><img src="https://s.w.org/style/images/codeispoetry.png?1" alt="Code is Poetry." /></p>
